@@ -1,7 +1,6 @@
-# Taken from Time::HiRes
+# Adapted from Time::HiRes
 use POSIX qw(uname);
 if (substr((uname())[2], 2) <= 6) {
 	$self->{LIBS} = ['-lposix4'];
-else {
-	$self->{LIBS} = ['-lrt'];
+	$self->{DEFINE} = psem_define('-lposix4');
 }
